==> Products.CMFQuickInstallerTool-3.0.16.tar.gz: Products.CMFQuickInstallerTool-3.0.16/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup

version = '3.0.16'
long_description = open("README.rst").read()
long_description += '\n'
long_description += open("CHANGES.rst").read()

setup(
    name='Products.CMFQuickInstallerTool',
    version=version,
    description="A facility for comfortable activation/deactivation of CMF "
                "compliant add ons for Zope.",
    long_description=long_description,
    classifiers=[
        "Framework :: Plone",
        "Framework :: Plone :: 4.3",
        "Framework :: Plone :: 5.0",
        "Framework :: Plone :: 5.1",
        "Framework :: Zope2",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.6",
        "Programming Language :: Python :: 2.7",
    ],
    keywords='Zope CMF Plone quickinstall install activation',
    author='Philipp Auersperg',
    author_email='plone-developers@lists.sourceforge.net',
    maintainer='Hanno Schlichting',
    maintainer_email='hannosch@plone.org',
    url='https://pypi.python.org/pypi/Products.CMFQuickInstallerTool',
    license='GPL',
    packages=find_packages(exclude=['ez_setup']),
    namespace_packages=['Products'],
    include_package_data=True,
    zip_safe=False,
    extras_require=dict(
      test=[
          'zope.testing',
          'plone.app.testing',
          'plone.protect>=2.0.2',
      ]
    ),
    install_requires=[
      'setuptools',
      'six',
      'zope.annotation',
      'zope.component',
      'zope.i18nmessageid',
      'zope.interface',
      'Products.CMFCore',
      'Products.ExternalMethod',
      'Products.GenericSetup>=1.8.1',
      'Acquisition',
      'DateTime',
      'Zope2',
    ],
)

==> Products.CMFQuickInstallerTool-4.0.0.tar.gz: Products.CMFQuickInstallerTool-4.0.0/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import find_packages
from setuptools import setup

version = '4.0.0'
long_description = open("README.rst").read()
long_description += '\n'
long_description += open("CHANGES.rst").read()

setup(
    name='Products.CMFQuickInstallerTool',
    version=version,
    description="A facility for comfortable activation/deactivation of CMF "
                "compliant add ons for Zope.",
    long_description=long_description,
    classifiers=[
        "Framework :: Plone",
        "Framework :: Plone :: 5.2",
        "Framework :: Zope2",
        "License :: OSI Approved :: GNU General Public License (GPL)",
        "Programming Language :: Python",
        "Programming Language :: Python :: 2.7",
        "Programming Language :: Python :: 3.6",
        "Programming Language :: Python :: 3.7",
    ],
    keywords='Zope CMF Plone quickinstall install activation',
    author='Philipp Auersperg',
    author_email='plone-developers@lists.sourceforge.net',
    maintainer='Hanno Schlichting',
    maintainer_email='hannosch@plone.org',
    url='https://pypi.org/project/Products.CMFQuickInstallerTool',
    license='GPL',
    packages=find_packages(),
    namespace_packages=['Products'],
    include_package_data=True,
    zip_safe=False,
    extras_require=dict(
      test=[
          'zope.testing',
          'plone.app.testing',
          'plone.protect>=2.0.2',
      ]
    ),
    install_requires=[
      'setuptools',
      'six',
      'zope.annotation',
      'zope.component',
      'zope.i18nmessageid',
      'zope.interface',
      'Products.CMFCore',
      'Products.ExternalMethod',
      'Products.GenericSetup>=1.8.1',
      'Acquisition',
      'DateTime',
      'Zope2',
    ],
)
